# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-11-23 09:25
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("testapp", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="yubikey_id",
            field=models.CharField(
                blank=True,
                max_length=12,
                validators=[django.core.validators.MinLengthValidator(12)],
            ),
        ),
    ]



import datetime
import environ
import os


root = environ.Path(__file__) - 1
env = environ.Env()
environ.Env.read_env(env_file=root(".env"))

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

SECRET_KEY = env.str("SECRET_KEY")
DEBUG = env.bool("DEBUG", default=False)
ALLOWED_HOSTS = env.list("ALLOWED_HOSTS", default=["*"])
CORS_ORIGIN_ALLOW_ALL = env.bool("CORS_ORIGIN_ALLOW_ALL", default=False)
DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "rest_framework",
    "rest_framework.authtoken",
    "corsheaders",
    "drf_yasg",
    "testapp",
    "trench",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "corsheaders.middleware.CorsMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

ROOT_URLCONF = "testapp.urls"
TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": "db.sqlite3",
    }
}

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",  # noqa: E501
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

LANGUAGE_CODE = "en-us"

TIME_ZONE = "UTC"

USE_I18N = True

USE_L10N = True

USE_TZ = True


STATIC_URL = "/static/"

EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"

REST_FRAMEWORK = {
    "DEFAULT_AUTHENTICATION_CLASSES": [
        "rest_framework_simplejwt.authentication.JWTAuthentication",
    ],
    "DEFAULT_SCHEMA_CLASS": "rest_framework.schemas.coreapi.AutoSchema",
}

AUTH_USER_MODEL = "testapp.User"

JWT_AUTH = {
    "JWT_EXPIRATION_DELTA": datetime.timedelta(
        days=env.int("JWT_EXPIRATION_DELTA_DAYS", default=7)
    ),
}

SIMPLE_JWT = {
    "USER_ID_FIELD": "username",
    "USER_ID_CLAIM": "username",
    "ALGORITHM": "HS256",
}

TRENCH_AUTH = {
    "CONFIRM_DISABLE_WITH_CODE": True,
    "CONFIRM_BACKUP_CODES_REGENERATION_WITH_CODE": True,
    "BACKUP_CODES_CHARACTERS": "0123456789",
    "MFA_METHODS": {
        "sms_twilio": {
            "VERBOSE_NAME": "sms",
            "VALIDITY_PERIOD": 60,
            "HANDLER": "trench.backends.twilio.TwilioMessageDispatcher",
            "SOURCE_FIELD": "phone_number",
            "TWILIO_VERIFIED_FROM_NUMBER": env(
                "TWILIO_VERIFIED_FROM_NUMBER",
                default="",
            ),
        },
        "sms_api": {
            "VERBOSE_NAME": "sms",
            "VALIDITY_PERIOD": 60,
            "HANDLER": "trench.backends.sms_api.SMSAPIMessageDispatcher",
            "SOURCE_FIELD": "phone_number",
            "SMSAPI_ACCESS_TOKEN": "token",
            "SMSAPI_FROM_NUMBER": "123 456 789",
        },
        "email": {
            "VERBOSE_NAME": "email",
            "VALIDITY_PERIOD": 60,
            "HANDLER": "trench.backends.basic_mail.SendMailMessageDispatcher",
            "SOURCE_FIELD": "email",
            "EMAIL_SUBJECT": "Your verification code",
            "EMAIL_PLAIN_TEMPLATE": "trench/backends/email/code.txt",
            "EMAIL_HTML_TEMPLATE": "trench/backends/email/code.html",
        },
        "app": {
            "VERBOSE_NAME": "app",
            "VALIDITY_PERIOD": 60,
            "USES_THIRD_PARTY_CLIENT": True,
            "HANDLER": "trench.backends.application.ApplicationMessageDispatcher",
        },
        "yubi": {
            "VERBOSE_NAME": "yubi",
            "HANDLER": "trench.backends.yubikey.YubiKeyMessageDispatcher",
            "YUBICLOUD_CLIENT_ID": env("YUBICLOUD_CLIENT_ID", default=""),
        },
    },
}



# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-09-26 12:35
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("testapp", "0002_user_yubikey_id"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="user",
            name="yubikey_id",
        ),
    ]



from django.contrib.auth import get_user_model

from rest_framework import serializers
from rest_framework.serializers import ModelSerializer
from testapp.models import User


class ExtendedUserSerializer(ModelSerializer):
    phone_number = serializers.CharField(allow_blank=True)

    class Meta:
        model = get_user_model()
        fields = ("id", "email", "username", "phone_number")
        read_only_fields = (User.USERNAME_FIELD,)



from django.contrib import admin
from django.contrib.auth.admin import UserAdmin as BaseUserAdmin

from .models import User


@admin.register(User)
class UserAdmin(BaseUserAdmin):

    model = User
    fieldsets = BaseUserAdmin.fieldsets



from django.conf.urls import include
from django.contrib import admin
from django.urls import re_path

from drf_yasg import openapi
from drf_yasg.views import get_schema_view
from rest_framework.permissions import AllowAny

from trench import __version__


schema_view = get_schema_view(
    openapi.Info(
        title="Django Trench example app API",
        default_version=__version__,
        description="This example illustrates the usage of Django Trench package",
        contact=openapi.Contact(email="code@merixstudio.com"),
        license=openapi.License(name="MIT License"),
    ),
    public=True,
    permission_classes=(AllowAny,),
)

urlpatterns = (
    re_path(r"^admin/", admin.site.urls),
    re_path(r"^auth/", include("trench.urls")),
    re_path(r"^auth/jwt/", include("trench.urls.jwt")),
    re_path(r"^auth/token/", include("trench.urls.authtoken")),
    re_path(
        r"^swagger/",
        schema_view.with_ui("swagger", cache_timeout=0),
        name="schema-swagger-ui",
    ),
)
